import { type Entity, Component, MotorComponent, SensorComponent, SuctionGripperComponent, Sequence, Wait, Handle } from "prototwin";

export class GantryController extends Component {
    public sensor: Handle<SensorComponent>;
    public horizontal: Handle<MotorComponent>;
    public vertical: Handle<MotorComponent>;
    public gripper: Handle<SuctionGripperComponent>;

    constructor(entity: Entity) {
        super(entity);
        this.sensor = this.handle(SensorComponent);
        this.horizontal = this.handle(MotorComponent);
        this.vertical = this.handle(MotorComponent);
        this.gripper = this.handle(SuctionGripperComponent);
    }

    public override initialize() {
        const sequence = new Sequence(true);
        sequence.add(() => Wait.value(this.sensor.value!.io.state, true)) // Blocked
                .add(() => this.horizontal.value!.moveTo(0.26)) // Left
                .add(() => this.vertical.value!.moveTo(0.995)) // Down
                .add(() => this.gripper.value!.state = true) // Grip
                .add(() => this.vertical.value!.moveTo(0.5)) // Up
                .add(() => this.horizontal.value!.moveTo(1.74)) // Right
                .add(() => this.vertical.value!.moveTo(0.9)) // Down
                .add(() => this.gripper.value!.state = false) // Release
                .add(() => this.vertical.value!.moveTo(0.5)) // Up
                .start();
    }
}
